@@ -22,7 +22,8 @@ class CuemiacAlignedView(AbstractCuemiacView, CuemiacAlignedWindow):
         self._controller.register_view(self)
         self.applet = applet
         
-        GconfStore.get_instance().connect("entry-width-changed", self._on_entry_width_changed)
+        GconfStore.get_instance().connect("entry-width-changed",
+                                          lambda s, w: self._change_entry_width(w))
         
         self.set_type_hint (gtk.gdk.WINDOW_TYPE_HINT_MENU)
         self.applet.set_applet_flags(gnomeapplet.EXPAND_MINOR)
@@ -43,7 +44,8 @@ class CuemiacAlignedView(AbstractCuemiacView, CuemiacAlignedWindow):
 
         self.set_role("deskbar-search-window")
         
-        self.get_entry().set_width_chars(self._model.get_entry_width())
+        entry_width = self._model.get_entry_width()
+        self._change_entry_width(entry_width)
         
         # VBox
         self.add(self.vbox_main)
@@ -138,7 +140,9 @@ class CuemiacAlignedView(AbstractCuemiacView, CuemiacAlignedWindow):
         else:
             self.vbox_main.reorder_child(self.results_box, 0)
             self.vbox_main.reorder_child(self.header, 2)
-            
-    def _on_entry_width_changed(self, store, width):
-        self.get_entry().set_width_chars(width)
+       
+    def _change_entry_width(self, entry_width):
+        if entry_width < 10:
+            entry_width = 10
+        self.get_entry().set_width_chars(entry_width)
     
\ No newline at end of file
